@@ -1,6 +1,5 @@
 #include <stdio.h>
 #include <sys/time.h>
-#include <stdlib.h>
 
 #include "sipuri.h"
 #include "sipuser.h"
@@ -57,6 +56,7 @@ void SipCallMember::requestSubscribe( int expiresTime, const QString &body, cons
 
 void SipCallMember::sendRequestSubscribe( QString username, QString password )
 {
+	call->transactions.clear();
 	if( !username.isEmpty() && !password.isEmpty() &&
 			( authstate == authState_AuthenticationRequired ||
 			authstate == authState_AuthenticationRequiredWithNewPassword ) ) {
@@ -174,6 +174,7 @@ void SipCallMember::requestNotify( const QString &body, const MimeContentType &b
 
 void SipCallMember::sendRequestNotify( QString username, QString password )
 {
+	call->transactions.clear();
 	if( !username.isEmpty() && !password.isEmpty() &&
 	    ( authstate == authState_AuthenticationRequired ||
 	    authstate == authState_AuthenticationRequiredWithNewPassword ) ) {
@@ -414,7 +415,7 @@ void SipCallMember::handlingInviteResponse( void )
 	if( state == state_Connected ) {
 		if( local->getStatus().getCode() >= 200 ) {
 			if( local->getStatus().getCode() == 200 ) {
-				statusdesc = "Response: " + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Response: ") + local->getStatus().getReasonPhrase();
 				statusUpdated( this );
 			} else if( local->getStatus().getCode() == 407 ) {
 				proxyauthstr = local->getFinalProxyAuthString();
@@ -429,7 +430,7 @@ void SipCallMember::handlingInviteResponse( void )
 				return;
 			} else {
 				state = state_Disconnected;
-				statusdesc = "Response: " + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Response: ") + local->getStatus().getReasonPhrase();
 			}
 			op = opIdle;
 			local = 0;
@@ -450,7 +451,7 @@ void SipCallMember::handlingInviteResponse( void )
 
 			} else {
 				state = state_Disconnected;
-				statusdesc = "Response: " + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Response: ") + local->getStatus().getReasonPhrase();
 			}
 			op = opIdle;
 			local = 0;
@@ -473,10 +474,10 @@ void SipCallMember::handlingInviteResponse( void )
 			if( local->getStatus().getCode() < 300 ) {
 				call->setCallStatus( SipCall::callInProgress );
 				state = state_Connected;
-				statusdesc = "Connected: " + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Connected: ") + local->getStatus().getReasonPhrase();
 			} else if( local->getStatus().getCode() < 400 ) {
 				state = state_Redirected;
-				statusdesc = "Redirected: " + local->getStatus().getReasonPhrase();
+				statusdesc = tr("Redirected: ") + local->getStatus().getReasonPhrase();
 				redirectlist = local->getFinalContactList();
 			} else {
 				if(local->getStatus().getCode() == 407){
@@ -499,7 +500,7 @@ void SipCallMember::handlingInviteResponse( void )
 
 				} else {
 					state = state_Disconnected;
-					statusdesc = "Call Failed: " + local->getStatus().getReasonPhrase();
+					statusdesc = "!!" + tr("Call Failed: ") + local->getStatus().getReasonPhrase();
 				}
 			}
 			op = opIdle;
@@ -522,7 +523,7 @@ void SipCallMember::requestDisconnect( void )
 		disconnect( local, 0, this, 0 );
 	}
 	state = state_Disconnecting;
-	statusdesc = "Disconnecting";
+	statusdesc = tr("Disconnecting");
 	local = call->newRequest( this, Sip::BYE );
 	if( local ) {
 		connect( local, SIGNAL( statusUpdated() ), this, SLOT( localStatusUpdated() ) );
@@ -534,11 +535,11 @@ void SipCallMember::requestTransfer( const SipUri &transferto,
 {
 	if( state == state_Disconnected ) return;
 	state = state_Disconnecting;
-	statusdesc = "Transfering";
+	statusdesc = tr("Transfering");
 	local = call->newRequest( this, Sip::REFER, body, bodytype, transferto );
 	connect( local, SIGNAL( statusUpdated() ), this, SLOT( localStatusUpdated() ) );
 	state = state_Disconnecting;
-	statusdesc = "Disconnecting";
+	statusdesc = tr("Disconnecting");
 	local = call->newRequest( this, Sip::BYE );
 	if( local ) {
 		connect( local, SIGNAL( statusUpdated() ), this, SLOT( localStatusUpdated() ) );
@@ -552,7 +553,7 @@ void SipCallMember::requestOptions( const QString &body, const MimeContentType &
 		local->cancelRequest();
 		disconnect( local, 0, this, 0 );
 	}
-	statusdesc = "Querying options";
+	statusdesc = tr("Querying options");
 	local = call->newRequest( this, Sip::OPTIONS, body, bodytype );
 	connect( local, SIGNAL( statusUpdated() ), this, SLOT( localStatusUpdated() ) );
 	statusUpdated( this );
@@ -767,6 +768,7 @@ SipTransaction *SipCall::newRequest( SipCallMember *member, Sip::Method meth,
 {
 	SipTransaction *trans = new SipTransaction( lastseq++, member, this );
 	if( trans->sendRequest( meth, body, bodytype, transferto, proxyauthentication, expiresTime ) ) {
+		transactions.clear();
 		transactions.append( trans );
 
 		// Audit the call
@@ -783,6 +785,7 @@ SipTransaction *SipCall::newRequest( SipCallMember *member, Sip::Method meth,
 SipTransaction *SipCall::newRegister( const SipUri &registerserver, int expiresTime, const QString &authentication,
 	const QString &proxyauthentication, const QString &qvalue, const QString &body, const MimeContentType &bodytype )
 {
+	transactions.clear();
 	localuri.setTag( QString::null );
 	SipTransaction *trans = new SipTransaction( lastseq++, new SipCallMember( this, localuri ), this );
 	transactions.append( trans );
@@ -790,7 +793,7 @@ SipTransaction *SipCall::newRegister( const SipUri &registerserver, int expiresT
 	return trans;
 }
 
-bool SipCall::sendRequest( SipMessage *reqmsg, bool contact, const SipUri &proxy )
+bool SipCall::sendRequest( SipMessage *reqmsg, bool contact, const SipUri &proxy, const QString &branch )
 {
 	reqmsg->insertHeader( SipHeader::From, localuri.nameAddr() );
 	reqmsg->insertHeader( SipHeader::Call_ID, callid );
@@ -834,7 +837,7 @@ bool SipCall::sendRequest( SipMessage *reqmsg, bool contact, const SipUri &proxy
 			}
 		}
 	}
-	return parent->sendRequest( reqmsg, contact, proxy );
+	return parent->sendRequest( reqmsg, contact, proxy, branch );
 }
 
 void SipCall::sendResponse( SipMessage *responsemsg, bool contact )
