@@ -9,20 +9,36 @@
 #include <qlayout.h>
 #include <qdialog.h>
 
+#include "../config.h"
 #include "callaudio.h"
 #include "dspoutoss.h"
 #include "audiocontrol.h"
 
-AudioControl::AudioControl( CallAudio *callaudio, QWidget *parent, const char *name )
+AudioControl::AudioControl( QWidget *parent, const char *name )
 	: QDialog( parent, QString( name ) + tr("Audio Properties"), true )
 {
-	a = callaudio;
 	QVBox *vbox = new QVBox( this );
 	vbox->setMargin( 3 );
 	vbox->setSpacing( 3 );
 	QVBoxLayout *vboxl = new QVBoxLayout( this, 5 );
 	vboxl->addWidget( vbox );
-	
+
+#ifdef ALSA_SUPPORT
+	bg4 = new QHButtonGroup( tr("Audio Mode"), vbox );
+	ossButton = new QRadioButton( "OSS", bg4 );
+	bg4->insert( ossButton, oss );
+	connect( ossButton, SIGNAL( clicked() ), this, SLOT( ossButtonClicked() ) );
+	alsaButton = new QRadioButton( "ALSA", bg4 );
+	bg4->insert( alsaButton, alsa );
+	connect( alsaButton, SIGNAL( clicked() ), this, SLOT( alsaButtonClicked() ) );
+#endif
+
+#ifdef JACK_SUPPORT
+	jackButton = new QRadioButton( "Jack", bg4 );
+	bg4->insert( jackButton, jack );
+	connect( jackButton, SIGNAL( clicked() ), this, SLOT( jackButtonClicked() ) );
+#endif
+
 	bg2 = new QHButtonGroup( tr("OSS Device Mode"), vbox );
 	rwButton = new QRadioButton( tr("ReadWrite"), bg2 );
 	bg2->insert( rwButton, rw );
@@ -30,17 +46,15 @@ AudioControl::AudioControl( CallAudio *callaudio, QWidget *parent, const char *n
 	bg2->insert( rowoButton, rowo );
 	connect( rwButton, SIGNAL( clicked() ), this, SLOT( rwButtonClicked() ) );
 	connect( rowoButton, SIGNAL( clicked() ), this, SLOT( rowoButtonClicked() ) );
-
+	QSettings settings;
+	QString dev = settings.readEntry( "/kphone/audio/oss-filename" );
+	QString dev2 = settings.readEntry( "/kphone/audio/oss-filename2" );
 	(void) new QLabel( tr("Device for WriteOnly or ReadWrite:"), vbox );
-	dspdev = new QLineEdit( a->getOSSFilename(), vbox );
+	dspdev = new QLineEdit( dev, vbox );
 	dspdev->setMinimumWidth( fontMetrics().maxWidth() * 20 );
-	dspdev->setText( a->getOSSFilename() );
-
 	(void) new QLabel( tr("Device for ReadOnly:"), vbox );
-	dspdev2 = new QLineEdit( a->getOSSFilename2(), vbox );
+	dspdev2 = new QLineEdit( dev2, vbox );
 	dspdev2->setMinimumWidth( fontMetrics().maxWidth() * 20 );
-	dspdev2->setText( a->getOSSFilename2() );
-
 	bg1 = new QHButtonGroup( tr("Preferred Codec"), vbox );
 	QRadioButton *ulawButton = new QRadioButton( tr("G711u"), bg1 );
 	bg1->insert( ulawButton, ulaw );
@@ -49,16 +63,36 @@ AudioControl::AudioControl( CallAudio *callaudio, QWidget *parent, const char *n
 	QRadioButton *ilbcButton = new QRadioButton( tr("iLBC"), bg1 );
 	bg1->insert( ilbcButton, ilbc );
 
-	QSettings settings;
-	QString mode = settings.readEntry( "/kphone/audio/mode", "readwrite" );
-	if( mode == "readwrite" ) {
-		rwButton->setChecked(TRUE);
+#ifdef ALSA_SUPPORT
+	QString audiomode = settings.readEntry( "/kphone/audio/audio", "alsa" );
+	if( audiomode == "alsa" ) {
+		alsaButton->setChecked(TRUE);
+		rwButton->setEnabled(FALSE);
+		rowoButton->setEnabled(FALSE);
+		dspdev->setEnabled(FALSE);
 		dspdev2->setEnabled(FALSE);
+#ifdef JACK_SUPPORT
+	} else if( audiomode == "jack" ) {
+		jackButton->setChecked(TRUE);
+		rwButton->setEnabled(FALSE);
+		rowoButton->setEnabled(FALSE);
+		dspdev->setEnabled(FALSE);
+		dspdev2->setEnabled(FALSE);
+#endif
 	} else {
-		rowoButton->setChecked(TRUE);
-		dspdev2->setEnabled(TRUE);
+		ossButton->setChecked(TRUE);
+		rwButton->setEnabled(TRUE);
+		QString mode = settings.readEntry( "/kphone/audio/mode", "readwrite" );
+		if( mode == "readwrite" ) {
+			rwButton->setChecked(TRUE);
+			dspdev2->setEnabled(FALSE);
+		} else {
+			rowoButton->setChecked(TRUE);
+			dspdev2->setEnabled(TRUE);
+		}
 	}
-	
+#endif
+
 	QString codec = settings.readEntry( "/kphone/audio/Codec", "ULAW" );
 	if( codec == "ULAW" ) {
 		ulawButton->setChecked(TRUE);
@@ -109,6 +143,31 @@ AudioControl::~AudioControl( void )
 {
 }
 
+void AudioControl::ossButtonClicked( void )
+{
+	bg2->setEnabled(TRUE);
+	dspdev->setEnabled(TRUE);
+	if (rwButton->isChecked() ) {
+		dspdev2->setEnabled(FALSE);
+	} else {
+		dspdev2->setEnabled(TRUE);
+	}
+}
+
+void AudioControl::alsaButtonClicked( void )
+{
+	bg2->setEnabled(FALSE);
+	dspdev->setEnabled(FALSE);
+	dspdev2->setEnabled(FALSE);
+}
+
+void AudioControl::jackButtonClicked( void )
+{
+	bg2->setEnabled(FALSE);
+	dspdev->setEnabled(FALSE);
+	dspdev2->setEnabled(FALSE);
+}
+
 void AudioControl::rwButtonClicked( void )
 {
 	dspdev2->setEnabled(FALSE);
@@ -127,23 +186,17 @@ void AudioControl::slotOk( void )
 
 void AudioControl::slotApply( void )
 {
-	a->setOSSFilename( dspdev->text() );
-	a->setOSSFilename2( dspdev2->text() );
-	a->saveAudioSettings();
 	QSettings settings;
 
 	switch( bg1->id( bg1->selected() ) ) {
 		case ulaw:
 			settings.writeEntry( "/kphone/audio/Codec", "ULAW");
-			a->setCodec( codecULAW );
 			break;
 		case gsm:
 			settings.writeEntry( "/kphone/audio/Codec", "GSM");
-			a->setCodec( codecGSM );
 			break;
 		case ilbc:
 			settings.writeEntry( "/kphone/audio/Codec", "ILBC");
-			a->setCodec( codecILBC );
 			break;
 	}
 
@@ -156,6 +209,22 @@ void AudioControl::slotApply( void )
 			break;
 	}
 
+#ifdef ALSA_SUPPORT
+	switch( bg4->id( bg4->selected() ) ) {
+#ifdef JACK_SUPPORT
+		case jack:
+			settings.writeEntry( "/kphone/audio/audio", "jack");
+			break;
+#endif
+		case alsa:
+			settings.writeEntry( "/kphone/audio/audio", "alsa");
+			break;
+		case oss:
+			settings.writeEntry( "/kphone/audio/audio", "oss");
+			break;
+	}
+#endif
+
 	int payload;
 	switch( bg3->id( bg3->selected() ) ) {
 		case size80:
@@ -166,7 +235,6 @@ void AudioControl::slotApply( void )
 			payload = 160;
 			break;
 	}
-	a->setPayload( payload );
 	settings.writeEntry( "/kphone/dsp/SizeOfPayload", payload );
 
 	switch( ringing->id( ringing->selected() ) ) {
@@ -181,16 +249,12 @@ void AudioControl::slotApply( void )
 
 void AudioControl::slotCancel( void )
 {
-	dspdev->setText( a->getOSSFilename() );
-	dspdev2->setText( a->getOSSFilename2() );
 	QDialog::reject();
 }
 
-VideoControl::VideoControl( CallAudio *callaudio,
-	QWidget *parent, const char *name )
-	: QDialog( parent, QString( name ) +  tr("Video Properties"), true )
+VideoControl::VideoControl( QWidget *parent, const char *name )
+	: QDialog( parent, QString( name ) + tr("Video Properties"), true )
 {
-	a = callaudio;
 	QVBox *vbox = new QVBox( this );
 	vbox->setMargin( 3 );
 	vbox->setSpacing( 3 );
@@ -243,17 +307,14 @@ void VideoControl::slotOk( void )
 
 void VideoControl::slotApply( void )
 {
-	a->setVideoSW( videoSW->text() );
 	QSettings settings;
 	settings.writeEntry( "/kphone/video/videoSW", videoSW->text() );
 	switch( bg1->id( bg1->selected() ) ) {
 		case h261:
 			settings.writeEntry( "/kphone/video/codec", "h261");
-			a->setVideoCodec( codecH261 );
 			break;
 		case h263:
 			settings.writeEntry( "/kphone/video/codec", "h263");
-			a->setVideoCodec( codecH263 );
 			break;
 	}
 }
