@@ -7,16 +7,18 @@
 class QLineEdit;
 class QRadioButton;
 class CallAudio;
-class DspOutOss;
 
 class AudioControl : public QDialog
 {
 	Q_OBJECT
 public:
-	AudioControl( CallAudio *callaudio, QWidget *parent = 0, const char *name = 0 );
+	AudioControl( QWidget *parent = 0, const char *name = 0 );
 	~AudioControl( void );
 
 protected slots:
+	void ossButtonClicked( void );
+	void alsaButtonClicked( void );
+	void jackButtonClicked( void );
 	void rwButtonClicked( void );
 	void rowoButtonClicked( void );
 	void slotOk( void );
@@ -24,6 +26,7 @@ protected slots:
 	void slotCancel( void );
 
 private:
+	enum audiomode { oss, alsa, jack };
 	enum rdwr { rw, rowo };
 	enum Codecs { ulaw, gsm, ilbc };
 	enum SizeOfPayload { size80, size160 };
@@ -31,6 +34,7 @@ private:
 	QButtonGroup *bg1;
 	QButtonGroup *bg2;
 	QButtonGroup *bg3;
+	QButtonGroup *bg4;
 	CallAudio *a;
 	QLineEdit *dspdev;
 	QLineEdit *dspdev2;
@@ -39,13 +43,16 @@ private:
 	QPushButton *cancelPushButton;
 	QRadioButton *rwButton;
 	QRadioButton *rowoButton;
+	QRadioButton *ossButton;
+	QRadioButton *alsaButton;
+	QRadioButton *jackButton;
 };
 
 class VideoControl : public QDialog
 {
 	Q_OBJECT
 public:
-	VideoControl( CallAudio *callaudio, QWidget *parent = 0, const char *name = 0 );
+	VideoControl( QWidget *parent = 0, const char *name = 0 );
 	~VideoControl( void );
 
 protected slots:
@@ -56,7 +63,6 @@ protected slots:
 private:
 	enum Codecs { h261, h263 };
 	QButtonGroup *bg1;
-	CallAudio *a;
 	QLineEdit *videoSW;
 	QPushButton *okPushButton;
 	QPushButton *cancelPushButton;
