@@ -3,7 +3,9 @@
 #include <unistd.h>
 #include <signal.h>
 #include <qsettings.h>
+#include <qmessagebox.h>
 
+#include "../config.h"
 #include "../dissipate2/sipprotocol.h"
 #include "../dissipate2/sipcall.h"
 #include "../dissipate2/sdp.h"
@@ -11,15 +13,32 @@
 #include "dspaudioin.h"
 #include "dspoutrtp.h"
 #include "dspoutoss.h"
+#include "kphoneview.h"
+
+#ifdef ALSA_SUPPORT
+#include "dspoutalsa.h"
+#endif
+
+#ifdef JACK_SUPPORT
+#include "dspaudiojackout.h"
+#include "dspaudiojackin.h"
+#endif
+
 #include "callaudio.h"
 
-CallAudio::CallAudio( void )
+CallAudio::CallAudio(  KPhoneView *phoneview )
 {
+	view = phoneview;
+	if( view->useStunSrv() ) {
+		setStunSrv( view->getStunSrv() );
+	}
+	jack_audioout = 0;
+	jack_audioin = 0;
 	output = 0;
 	input = 0;
 	curcall = 0;
 	curmember = 0;
-	useoss = true;
+	audiomode = oss;
 	setOSSFilename( QString::null );
 	setOSSFilename2( QString::null );
 	setVideoSW( QString::null );
@@ -55,13 +74,22 @@ CallAudio::~CallAudio( void )
 	}
 }
 
-void CallAudio::useOSS( void )
+void CallAudio::setAudiomode( QString str )
 {
-	if( useoss == true ) return;
-	useoss = true;
+	if( str.upper() == "OSS" ) {
+		if( audiomode == oss ) return;
+		audiomode = oss;
+	} else if( str.upper() == "ALSA" ) {
+		if( audiomode == alsa ) return;
+		audiomode = alsa;
+	} else if( str.upper() == "JACK" ) {
+		if( audiomode == jack ) return;
+		audiomode = jack;
+	}
 	renegotiateCall();
 }
 
+
 void CallAudio::setOSSFilename( const QString &devname )
 {
 	if( devname == QString::null ) {
@@ -107,7 +135,7 @@ void CallAudio::audioIn( void )
 	}
 	DspOut *out;
 	DspOut *in;
-	if( useoss ) {
+	if( audiomode == oss ) {
 		DspOutRtp *outrtp;
 		if (symMedia) {
 			outrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum(), hostname, &socket );
@@ -120,7 +148,6 @@ void CallAudio::audioIn( void )
 		DspOutOss *inaudio = new DspOutOss( ossfilename2 );
 		QSettings settings;
 		if( settings.readEntry( "/kphone/audio/mode", "readwrite" ) == "readwrite" ) {
-			printf( tr("CallAudio: OSS device already open (readwrite)") + "\n" );
 			if( !inaudio->openDevice( audio_fd ) ) {
 				printf( tr("** audioIn: openDevice Failed.") + "\n" );
 			}
@@ -135,7 +162,49 @@ void CallAudio::audioIn( void )
 		in = inaudio;
 		printf( tr("CallAudio: Creating OSS->RTP Diverter") + "\n" );
 		input = new DspAudioIn( in, out );
+
+#ifdef ALSA_SUPPORT
+	} else if( audiomode == alsa ) {
+		DspOutRtp *outrtp;
+		if (symMedia) {
+			outrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum(), hostname, &socket );
+		} else {
+			outrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum(), hostname );
+		}
+		outrtp->setPortNum( portnum );
+		outrtp->openDevice( DspOut::WriteOnly );
+		outrtp->setPayload( payload );
+		DspOutAlsa *inaudio = new DspOutAlsa();
+		QSettings settings;
+		printf( "CallAudio: Opening ALSA device for Input \n" );
+		if( !inaudio->openDevice( DspOut::ReadOnly ) ) {
+			printf( "** audioIn: openDevice Failed.\n" );
+		}
+		out = outrtp;
+		in = inaudio;
+		printf( "CallAudio: Creating ALSA->RTP Diverter\n" );
+		input = new DspAudioIn( in, out );
+#endif
+
+#ifdef JACK_SUPPORT
+	} else if( audiomode == jack ) {
+		DspOutRtp *outrtp;
+		if (symMedia) {
+			outrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum(), hostname, &socket );
+		} else {
+			outrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum(), hostname );
+		}
+		outrtp->setPortNum( portnum );
+		outrtp->openDevice( DspOut::WriteOnly );
+		outrtp->setPayload( payload );
+		
+		printf( "CallAudio: Creating JACK->RTP Diverter\n" );
+		QString s = curcall->getCallId();
+		QString name = "Kphone-" + s.left( s.find( '@' )) + "-in";
+		jack_audioin = new DspAudioJackIn( outrtp, name );
+#endif
 	}
+
 	if( curcall->getCallType() == SipCall::videoCall ) {
 		printf( tr("CallAudio: Opening SW for video input and output") + "\n" );
 		pidVideo = fork();
@@ -171,6 +240,15 @@ void CallAudio::stopListeningAudio( void )
 		delete input;
 	}
 	input = 0;
+
+#ifdef JACK_SUPPORT
+	if( jack_audioin ) {
+		jack_audioin->exit();
+//		delete jack_audioin;
+	}
+	jack_audioin = 0;
+#endif
+
 	remote = SdpMessage::null;
 }
 
@@ -184,7 +262,7 @@ SdpMessage CallAudio::audioOut( void )
 	DspOut *in;
 	local.setIpAddress( Sip::getLocalAddress() );
 	local.setName( "The Funky Flow" );
-	if( useoss ) {
+	if( audiomode == oss ) {
 		DspOutRtp *inrtp;
 		if (symMedia) {
 			inrtp = new DspOutRtp( getRtpCodec(),
@@ -218,6 +296,79 @@ SdpMessage CallAudio::audioOut( void )
 		out = outoss;
 		printf( tr("CallAudio: Creating RTP->OSS Diverter") + "\n" );
 		output = new DspAudioOut( in, out );
+
+#ifdef ALSA_SUPPORT
+	} else if( audiomode == alsa ) {
+
+		DspOutRtp *inrtp;
+		if (symMedia) {
+			inrtp = new DspOutRtp( getRtpCodec(),
+				getRtpCodecNum(), QString::null, &socket );
+		} else {
+			inrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum() );
+		}
+		inrtp->setPayload( payload );
+		if( useStun ) {
+			inrtp->setStunSrv( stunSrv );
+		}
+		inrtp->openDevice( DspOut::ReadOnly );
+		local.setPort( inrtp->getPortNum() );
+		local.setVideoPort( inrtp->getVideoPortNum() );
+		DspOutAlsa *outalsa = new DspOutAlsa();
+		QSettings settings;
+/*
+		if( settings.readEntry( "/kphone/audio/mode", "readwrite" ) == "readwrite" ) {
+			printf( "CallAudio: Opening ALSA device %s for Input and Output\n", ossfilename.latin1() );
+//			if( !outalsa->openDevice( DspOut::ReadWrite ) ) {
+//				printf( "** audioOut: openDevice Failed.\n" );
+//			} else {
+//				audio_fd = outalsa->audio_fd;
+//			}
+		} else {
+			printf( "CallAudio: Opening OSS device %s for Output\n", ossfilename.latin1() );
+			if( !outalsa->openDevice( DspOut::WriteOnly )){
+				printf( "** audioOut: openDevice Failed.\n" );
+			}
+		}
+*/
+		printf( "CallAudio: Opening ALSA device for Output\n" );
+		if( !outalsa->openDevice( DspOut::WriteOnly )){
+			printf( "** audioOut: openDevice Failed.\n" );
+		}
+
+		in = inrtp;
+		out = outalsa;
+		printf( tr("CallAudio: Creating RTP->ALSA Diverter") + "\n" );
+		output = new DspAudioOut( in, out );
+#endif
+
+#ifdef JACK_SUPPORT
+	} else if( audiomode == jack ) {
+		DspOutRtp *inrtp;
+		if (symMedia) {
+			inrtp = new DspOutRtp( getRtpCodec(),
+				getRtpCodecNum(), QString::null, &socket );
+		} else {
+			inrtp = new DspOutRtp( getRtpCodec(), getRtpCodecNum() );
+		}
+		inrtp->setPayload( payload );
+		if( useStun ) {
+			inrtp->setStunSrv( stunSrv );
+		}
+		inrtp->openDevice( DspOut::ReadOnly );
+		local.setPort( inrtp->getPortNum() );
+		local.setVideoPort( inrtp->getVideoPortNum() );
+
+
+		printf( "CallAudio: Creating RTP->JACK Diverter\n" );
+		QString s = curcall->getCallId();
+		QString name = "Kphone-" + s.left( s.find( '@' )) + "-out";
+		jack_audioout = new DspAudioJackOut( inrtp, name );
+		if ( !jack_audioout->ok() ) {
+			QMessageBox::critical( view, "KPhone", "CallAudioJackOut: Error, jack server not running?" );
+		}
+#endif
+
 	}
 	return local;
 }
@@ -232,6 +383,15 @@ void CallAudio::stopSendingAudio( void )
 		delete output;
 	}
 	output = 0;
+
+#ifdef JACK_SUPPORT
+	if( jack_audioout ) {
+		jack_audioout->exit();
+		delete jack_audioout;
+	}
+	jack_audioout = 0;
+#endif
+
 	local.setIpAddress( "0.0.0.0" );
 	local.setName( "Idle" );
 	local.setPort( 0 );
@@ -248,18 +408,35 @@ void CallAudio::saveAudioSettings( void )
 void CallAudio::readAudioSettings( void )
 {
 	QSettings settings;
-	useOSS();
 	setOSSFilename( settings.readEntry( "/kphone/audio/oss-filename" ) );
 	setOSSFilename2( settings.readEntry( "/kphone/audio/oss-filename2" ) );
 	if( settings.readEntry( "/kphone/Symmetric/Media", "Yes" ) == "Yes" ) {
 		setSymMediaMode( true );
 	}
+
+	QString audiomodestr = settings.readEntry( "/kphone/audio/audio", "oss" );
+	setAudiomode( audiomodestr );
+
+	QString codec = settings.readEntry( "/kphone/audio/Codec", "ULAW" );
+	if( codec == "ULAW" ) {
+		setCodec( codecULAW );
+	} else if( codec == "GSM" ) {
+		setCodec( codecGSM );
+	} else if( codec == "ILBC" ) {
+		setCodec( codecILBC );
+	}
 }
 
 void CallAudio::readVideoSettings( void )
 {
 	QSettings settings;
 	setVideoSW( settings.readEntry( "/kphone/video/videoSW", "/usr/local/bin/vic"  ) );
+	QString videoCodec = settings.readEntry( "/kphone/video/codec", "h261" );
+	if( videoCodec == "h261" ) {
+		setVideoCodec( codecH261 );
+	} else if( videoCodec == "h263" ) {
+		setVideoCodec( codecH263 );
+	}
 }
 
 void CallAudio::setCurrentCall( SipCall *newcall )
@@ -426,10 +603,20 @@ void CallAudio::memberStatusUpdated(SipCallMember *member)
 		if( sdpm != remote ) {
 			remote = sdpm;
 			if( !sdpm.isOnHold() ) {
-				output->setCodec( getRtpCodec(), getRtpCodecNum() );
-				audioIn();
-				output->start();
-				input->start();
+				if( output ) {
+					output->setCodec( getRtpCodec(), getRtpCodecNum() );
+					audioIn();
+					output->start();
+					input->start();
+				} else if( jack_audioout ) {
+
+//					jack_audioout->setCodec( getRtpCodec(), getRtpCodecNum() );
+					audioIn();
+/*
+					jack_audioout->start();
+					jack_audioin->start();
+*/
+				}
 			}
 			statusUpdated();
 		}
