@@ -1,17 +1,9 @@
 #ifndef DSPTHREAD_H_INCLUDED
 #define DSPTHREAD_H_INCLUDED
 
+#include "../config.h"
 
-// if HAVE_THREAD is defined remove dspaudioin.moc.o
-// and dspaudioout.moc.o from Makefile.in
-
-#define HAVE_THREAD
-
-// use this only if absolutely necessary. (e.g. Redhat9)
-//#define QTHREAD_TERMINATE
-
-
-#ifdef HAVE_THREAD
+#ifdef QT_THREAD_SUPPORT
 #include <qthread.h>
 #else
 #include <qtimer.h>
@@ -25,7 +17,7 @@
 
 class DspOut;
 
-#ifdef HAVE_THREAD
+#ifdef QT_THREAD_SUPPORT
 class DspAudio : public QThread
 #else
 class DspAudio : public QObject
@@ -34,7 +26,7 @@ class DspAudio : public QObject
 public:
 	DspAudio( DspOut *in, DspOut *out );
 	virtual ~DspAudio( void );
-#ifdef HAVE_THREAD
+#ifdef QT_THREAD_SUPPORT
 	virtual void run();
 #else
 	virtual void start( void ) = 0;
@@ -67,7 +59,7 @@ protected:
 	char newTone;      // New DTMF tone to be generated (0 if none)
 	char currentTone;  // Tone currently being generated (0 if none)
 
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 	QTimer *timer;
 #endif
 
