@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <unistd.h>
 
+#include "../config.h"
 #include "audiobuffer.h"
 #include "dspout.h"
 #include "dspoutrtp.h"
@@ -61,7 +62,7 @@ void DspAudioIn::timerTick( void )
 	}
 }
 
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 void DspAudioIn::start( void )
 {
 	timer = new QTimer();
