@@ -3,11 +3,13 @@
 
 #include <dspaudio.h>
 
+#include "../config.h"
+
 class DspOut;
 
 class DspAudioIn : public DspAudio
 {
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 	Q_OBJECT
 #endif
 public:
@@ -19,7 +21,7 @@ public:
 	 */
 	virtual void timerTick( void );
 
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 	virtual void start( void );
 
 private slots:
