@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <assert.h>
 #include <unistd.h>
+#include "../config.h"
 #include "audiobuffer.h"
 #include "dspout.h"
 #include "dspoutrtp.h"
@@ -109,7 +110,7 @@ void DspAudioOut::timerTick( void )
 }
 
 
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 void DspAudioOut::start( void )
 {
 	timer = new QTimer();
