@@ -1,13 +1,14 @@
 #ifndef DSPAUDIOOUT_H_INCLUDED
 #define DSPAUDIOOUT_H_INCLUDED
 
+#include "../config.h"
 #include "dspaudio.h"
 
 class DspOut;
 
 class DspAudioOut : public DspAudio
 {
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 	Q_OBJECT
 #endif
 public:
@@ -19,7 +20,7 @@ public:
 	 */
 	virtual void timerTick( void );
 
-#ifndef HAVE_THREAD
+#ifndef QT_THREAD_SUPPORT
 	virtual void start( void );
 
 private slots:
