@@ -28,7 +28,7 @@ KPhone::KPhone( unsigned int listenport, QString prefix, bool looseRoute, bool s
 	}
 	userPrefix = "";
 	if( !prefix.isEmpty() ) {
-		setCaption( prefix );
+		setCaption( "kphone - " + prefix );
 		userPrefix = "_" + prefix + "_";
 	}
 	QSettings settings;
@@ -58,9 +58,6 @@ KPhone::KPhone( unsigned int listenport, QString prefix, bool looseRoute, bool s
 	else if( hvstr == "HideHop" ) { client->setHideViaMode( SipClient::HideHop ); }
 	else if( hvstr == "HideRoute" ) { client->setHideViaMode( SipClient::HideRoute ); }
 	user = new SipUser( client, SipUri( uristr ) );
-	audio = new CallAudio;
-	audio->readAudioSettings();
-	audio->readVideoSettings();
 
 	// Initially, none of the dialogs exist yet
 	qdial = 0;
@@ -72,7 +69,7 @@ KPhone::KPhone( unsigned int listenport, QString prefix, bool looseRoute, bool s
 	queryoptions = 0;
 	testoptions = 0;
 	trayIcon = NULL;
-	view = new KPhoneView( audio, client, user, this, getUserPrefix() );
+	view = new KPhoneView( client, user, this, getUserPrefix() );
 	connect( view, SIGNAL( stateChanged() ), this, SLOT( updateTrayIcon() ) );
 	if( uristr != QString::null ) {
 		p = "/kphone/" + getUserPrefix() + "Registration/";
@@ -122,7 +119,7 @@ KPhone::KPhone( unsigned int listenport, QString prefix, bool looseRoute, bool s
 	menuBar()->insertItem( tr("&Help"), popup );
 
 	if( registrations->getUseStun() ) {
-		audio->setStunSrv( registrations->getStunSrv() );
+		view->setStunSrv( registrations->getStunSrv() );
 		client->sendStunRequest( registrations->getStunSrv() );
 		QTimer *stun_timer = new QTimer( this );
 		connect( stun_timer, SIGNAL( timeout() ), this, SLOT( stun_timerTick() ) );
@@ -168,7 +165,7 @@ void KPhone::showUserInfo( void )
 void KPhone::showAudioPreferences( void )
 {
 	if( !audiocontrol ) {
-		audiocontrol = new AudioControl( audio, this, getUserPrefix() );
+		audiocontrol = new AudioControl( this, getUserPrefix() );
 	}
 	audiocontrol->show();
 }
@@ -176,7 +173,7 @@ void KPhone::showAudioPreferences( void )
 void KPhone::showVideoPreferences( void )
 {
 	if( !videocontrol ) {
-		videocontrol = new VideoControl( audio, this, getUserPrefix() );
+		videocontrol = new VideoControl( this, getUserPrefix() );
 	}
 	videocontrol->show();
 }
