@@ -37,24 +37,24 @@ PhoneBookAddIdentity::PhoneBookAddIdentity( QWidget *parent, const char *name )
 	QVBoxLayout *vboxl = new QVBoxLayout( this, 5 );
 	vboxl->addWidget( vbox );
 
-	(void) new QLabel( "Person:", vbox );
+	(void) new QLabel( tr("Person:"), vbox );
 	person = new QLineEdit( vbox );
-	(void) new QLabel( "Identity:", vbox );
+	(void) new QLabel( tr("Identity:"), vbox );
 	identity = new QLineEdit( vbox );
-	(void) new QLabel( "Description:", vbox );
+	(void) new QLabel( tr("Description:"), vbox );
 	description = new QLineEdit( vbox );
-	contact = new QCheckBox( "Add Identity to Contacts List", vbox );
+	contact = new QCheckBox( tr("Add Identity to Contacts List"), vbox );
 	description->setMinimumWidth( fontMetrics().maxWidth() * 20 );
 	QHBoxLayout *buttonBox;
 	buttonBox = new QHBoxLayout( vboxl, 6 );
 	QSpacerItem *spacer = new QSpacerItem( 0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	buttonBox->addItem( spacer );
-	okPushButton = new QPushButton( this, "ok button" );
-	okPushButton->setText( "OK" );
+	okPushButton = new QPushButton( this, tr("ok button") );
+	okPushButton->setText( tr("OK") );
 	okPushButton->setDefault( TRUE );
 	buttonBox->addWidget( okPushButton );
-	cancelPushButton = new QPushButton( this, "cancel button" );
-	cancelPushButton->setText( "Cancel" );
+	cancelPushButton = new QPushButton( this, tr("cancel button") );
+	cancelPushButton->setText( tr("Cancel") );
 	cancelPushButton->setAccel( Key_Escape );
 	buttonBox->addWidget( cancelPushButton );
 	connect( okPushButton, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
@@ -133,12 +133,12 @@ PhoneBookEditIdentity::PhoneBookEditIdentity( QWidget *parent, const char *name
 	QVBoxLayout *vboxl = new QVBoxLayout( this, 5 );
 	vboxl->addWidget( vbox );
 
-	(void) new QLabel( "Identity:", vbox );
+	(void) new QLabel( tr("Identity:"), vbox );
 	identity = new QLineEdit( vbox );
 	identity->setMinimumWidth( fontMetrics().maxWidth() * 20 );
-	(void) new QLabel( "Description:", vbox );
+	(void) new QLabel( tr("Description:"), vbox );
 	description = new QLineEdit( vbox );
-	contact = new QCheckBox( "Add Identity to Contacts List", vbox );
+	contact = new QCheckBox( tr("Add Identity to Contacts List"), vbox );
 
 // OK, Cancel
 	QHBoxLayout *buttonBox;
@@ -146,11 +146,11 @@ PhoneBookEditIdentity::PhoneBookEditIdentity( QWidget *parent, const char *name
 	QSpacerItem *spacer = new QSpacerItem( 0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	buttonBox->addItem( spacer );
 	okPushButton = new QPushButton( this, "ok button" );
-	okPushButton->setText( "OK" );
+	okPushButton->setText( tr("OK") );
 	okPushButton->setDefault( TRUE );
 	buttonBox->addWidget( okPushButton );
 	cancelPushButton = new QPushButton( this, "cancel button" );
-	cancelPushButton->setText( "Cancel" );
+	cancelPushButton->setText( tr("Cancel") );
 	cancelPushButton->setAccel( Key_Escape );
 	buttonBox->addWidget( cancelPushButton );
 	connect( okPushButton, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
@@ -219,7 +219,7 @@ PhoneBookEditPerson::PhoneBookEditPerson( QWidget *parent, const char *name )
 	QVBoxLayout *vboxl = new QVBoxLayout( this, 5 );
 	vboxl->addWidget( vbox );
 
-	(void) new QLabel( "Name:", vbox );
+	(void) new QLabel( tr("Name:"), vbox );
 	person = new QLineEdit( vbox );
 	person->setMinimumWidth( fontMetrics().maxWidth() * 20 );
 
@@ -229,11 +229,11 @@ PhoneBookEditPerson::PhoneBookEditPerson( QWidget *parent, const char *name )
 	QSpacerItem *spacer = new QSpacerItem( 0, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 	buttonBox->addItem( spacer );
 	okPushButton = new QPushButton( this, "ok button" );
-	okPushButton->setText( "OK" );
+	okPushButton->setText( tr("OK") );
 	okPushButton->setDefault( TRUE );
 	buttonBox->addWidget( okPushButton );
 	cancelPushButton = new QPushButton( this, "cancel button" );
-	cancelPushButton->setText( "Cancel" );
+	cancelPushButton->setText( tr("Cancel") );
 	cancelPushButton->setAccel( Key_Escape );
 	buttonBox->addWidget( cancelPushButton );
 	connect( okPushButton, SIGNAL( clicked() ), this, SLOT( slotOk() ) );
@@ -267,10 +267,6 @@ void PhoneBookEditPerson::slotCancel( void )
 PhoneBookParser::PhoneBookParser( QListView * t, bool CallRegister, bool rejectedContact )
 	: QXmlDefaultHandler()
 {
-	t->setSorting( 0 );
-	t->addColumn( "Identity" );
-	t->addColumn( "Contact" );
-	t->addColumn( "Description" );
 	rejected = 0;
 	listReceivedCalls = 0;
 	listMissedCalls = 0;
@@ -346,9 +342,9 @@ PhoneBook::PhoneBook(QString fileUserInfo, QWidget *parent, const char *name,
 	vbox->insertLayout( 0, headergrid );
 	phoneBook = new MenuListView( this );
 
-	phoneBook->addMenuItem( "Add", this, SLOT( clickAddButton() ) );
-	phoneBook->addMenuItem( "Edit", this, SLOT( clickEditButton() ) );
-	phoneBook->addMenuItem( "Remove", this, SLOT( clickRemoveButton() ) );
+	phoneBook->addMenuItem( tr("Add"), this, SLOT( clickAddButton() ) );
+	phoneBook->addMenuItem( tr("Edit"), this, SLOT( clickEditButton() ) );
+	phoneBook->addMenuItem( tr("Remove"), this, SLOT( clickRemoveButton() ) );
 	phoneBook->setMinimumWidth( fontMetrics().maxWidth() * 15 );
 
 	vbox->insertWidget( 1, phoneBook );
@@ -356,7 +352,10 @@ PhoneBook::PhoneBook(QString fileUserInfo, QWidget *parent, const char *name,
 		this, SLOT( setIdentity( QListViewItem * ) ) );
 	connect( phoneBook, SIGNAL( doubleClicked( QListViewItem * ) ),
 		this, SLOT( setIdentityAndDone( QListViewItem * ) ) );
-
+	phoneBook->setSorting( 0 );
+	phoneBook->addColumn( tr("Identity") );
+	phoneBook->addColumn( tr("Contact") );
+	phoneBook->addColumn( tr("Description") );
 	if( receivedCalls.count() == 0 && missedCalls.count() == 0 ) {
 		if( rejectedContacts.count() == 0 ) {
 			parser = new PhoneBookParser( phoneBook, false, false );
@@ -407,13 +406,13 @@ PhoneBook::PhoneBook(QString fileUserInfo, QWidget *parent, const char *name,
 	QHBox *hb1 = new QHBox( this );
 	hb1->setSpacing( 5 );
 	vbox->insertWidget( 3, hb1 );
-	add_button = new QPushButton( "Add", hb1 );
+	add_button = new QPushButton( tr("Add"), hb1 );
 	connect( add_button, SIGNAL( clicked() ), this, SLOT( clickAddButton() ) );
-	edit_button = new QPushButton( "Edit", hb1 );
+	edit_button = new QPushButton( tr("Edit"), hb1 );
 	connect( edit_button, SIGNAL( clicked() ), this, SLOT( clickEditButton() ) );
-	remove_button = new QPushButton( "Remove", hb1 );
+	remove_button = new QPushButton( tr("Remove"), hb1 );
 	connect( remove_button, SIGNAL( clicked() ), this, SLOT( clickRemoveButton() ) );
-	remove_button = new QPushButton( "Hide", hb1 );
+	remove_button = new QPushButton( tr("Hide"), hb1 );
 	connect( remove_button, SIGNAL( clicked() ), this, SLOT( clickHideButton() ) );
 	addIdentity = 0;
 	editIdentity = 0;
@@ -602,7 +601,7 @@ void PhoneBook::clickEditButton()
 			save();
 		}
 	} else {
-		QMessageBox::information( this, "KPhone", "Select first item." );
+		QMessageBox::information( this, tr("KPhone"), tr("Select first item.") );
 	}
 }
 
@@ -630,7 +629,7 @@ void PhoneBook::clickRemoveButton()
 				}
 			}
 			if( OK ) {
-				if( !QMessageBox::warning( this, "KPhone", "Are You Sure ?", "Yes", "No", "", 1) ) {
+				if( !QMessageBox::warning( this, tr("KPhone"), tr("Are You Sure ?"), tr("Yes"), tr("No"), "", 1) ) {
 					delete item;
 					item = 0;
 					save();
@@ -638,7 +637,7 @@ void PhoneBook::clickRemoveButton()
 			}
 		}
 	} else {
-		QMessageBox::information( this, "KPhone", "Select first item." );
+		QMessageBox::information( this, tr("KPhone"), tr("Select first item.") );
 	}
 }
 
