@@ -59,13 +59,13 @@ bool ContactParser::endElement( const QString&, const QString&, const QString& )
 	return TRUE;
 }
 
-KPhoneView::KPhoneView( CallAudio *callaudio, SipClient *c, SipUser *u, QWidget *parent, const char *name )
+KPhoneView::KPhoneView( SipClient *c, SipUser *u, QWidget *parent, const char *name )
 	: QWidget( parent, name ), client( c ), user( u )
 {
 	reg = 0;
+	kphone = (KPhone*)parent;
 	buttonSetOffline = false;
 	setSubscribeOffline = false;
-	callAudio = callaudio;
 	connect( client, SIGNAL( updateSubscribes() ),
 		this, SLOT( updateSubscribes() ) );
 	connect( client, SIGNAL( incomingInstantMessage( SipMessage * ) ),
@@ -150,22 +150,7 @@ KPhoneView::KPhoneView( CallAudio *callaudio, SipClient *c, SipUser *u, QWidget
 	QString uristr;
 	sipauthentication = new KSipAuthentication();
 	QSettings settings;
-	QString codec = settings.readEntry(
-		"/kphone/audio/Codec", "ULAW" );
-	if( codec == "ULAW" ) {
-		callAudio->setCodec( codecULAW );
-	} else if( codec == "GSM" ) {
-		callAudio->setCodec( codecGSM );
-	} else if( codec == "ILBC" ) {
-		callAudio->setCodec( codecILBC );
-	}
-	QString videoCodec = settings.readEntry(
-		"/kphone/video/codec", "h261" );
-	if( videoCodec == "h261" ) {
-		callAudio->setVideoCodec( codecH261 );
-	} else if( videoCodec == "h263" ) {
-		callAudio->setVideoCodec( codecH263 );
-	}
+
 	SipCall *newcall;
 	SipCallMember *member;
 	QString p = "/kphone/" + getUserPrefix() + "/local/";
@@ -372,6 +357,9 @@ void KPhoneView::incomingCall( SipCall *call, QString body )
 	if( call->getSubject() == QString::null ) {
 		call->setSdpMessageMask( body );
 		call->setSubject( tr("Incoming call") );
+		callAudio = new CallAudio( this );
+		callAudio->readAudioSettings();
+		callAudio->readVideoSettings();
 		KCallWidget *widget = new KCallWidget( 0, callAudio, call, this );
 		cwList.append( widget );
 		connect( widget, SIGNAL( redirectCall( const SipUri &, const QString & ) ),
@@ -461,6 +449,9 @@ void KPhoneView::contactCall()
 	}
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::StandardCall );
 	newcall->setSubject( user->getUri().uri() );
+	callAudio = new CallAudio( this );
+	callAudio->readAudioSettings();
+	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
 	widget->setRemote( subject );
@@ -482,6 +473,9 @@ void KPhoneView::contactVideoCall()
 	}
 	SipCall *newcall = new SipCall( user, QString::null, SipCall::videoCall );
 	newcall->setSubject( user->getUri().uri() );
+	callAudio = new CallAudio( this );
+	callAudio->readAudioSettings();
+	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
 	widget->setRemote( subject );
@@ -829,6 +823,9 @@ void KPhoneView::redirectCall( const SipUri &calluri, const QString &subject )
 {
 	SipCall *newcall = new SipCall( user );
 	newcall->setSubject( subject );
+	callAudio = new CallAudio( this );
+	callAudio->readAudioSettings();
+	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
 	widget->pleaseDial( calluri );
@@ -848,6 +845,9 @@ void KPhoneView::makeNewCall( void )
 	QString subject;
 	subject.sprintf( user->getUri().uri() );
 	newcall->setSubject( subject );
+	callAudio = new CallAudio( this );
+	callAudio->readAudioSettings();
+	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
 	widget->setRemote( lineeditCall->text() );
@@ -871,6 +871,9 @@ void KPhoneView::makeVideoCall( void )
 	QString subject;
 	subject.sprintf( user->getUri().uri() );
 	newcall->setSubject( subject );
+	callAudio = new CallAudio( this );
+	callAudio->readAudioSettings();
+	callAudio->readVideoSettings();
 	KCallWidget *widget = new KCallWidget( sipauthentication, callAudio, newcall, this );
 	cwList.append( widget );
 	widget->setRemote( lineeditCall->text() );
@@ -924,6 +927,30 @@ void KPhoneView::setContactsOnline( void )
 	stateUpdated( KPhoneView::ONLINE );
 }
 
+	void setStunSrv( QString );
+	bool getUseStun();
+	QString getStunStv();
+
+
+void KPhoneView::setStunSrv( QString stunuri )
+{
+	if( !stunuri.isEmpty() ) {
+		useStunProxy = true;
+		stunProxyUri = stunuri;
+	}
+}
+
+bool KPhoneView::useStunSrv( void )
+{
+	return useStunProxy;
+}
+
+QString KPhoneView::getStunSrv( void )
+{
+	return stunProxyUri;
+}
+
+
 void KPhoneView::kphoneQuit( void )
 {
 	KCallWidget *widget;
@@ -980,3 +1007,4 @@ bool KPhoneView::getState( void )
 {
 	return isOnline;
 }
+
