@@ -41,7 +41,7 @@ class KPhoneView : public QWidget
 	Q_OBJECT
 public:
 	enum State { ONLINE, OFFLINE };
-	KPhoneView( CallAudio *callaudio, SipClient *c, SipUser *u, QWidget *parent = 0, const char *name = 0 );
+	KPhoneView( SipClient *c, SipUser *u, QWidget *parent = 0, const char *name = 0 );
 	~KPhoneView( void );
 	void switchCall( SipCall *call );
 	void updateIdentity( SipUser *newUser, SipRegister *newReg = 0 );
@@ -49,6 +49,9 @@ public:
 	void updateContacts( QString file );
 	void setContactsOffline( void );
 	void setContactsOnline( void );
+	void setStunSrv( QString );
+	bool useStunSrv( void );
+	QString getStunSrv( void );
 	void kphoneQuit( void );
 	bool getState( void );
 
@@ -115,8 +118,8 @@ private:
 	bool setSubscribeOffline;
 	void updateWidgetList( void );
 	QString stateText( QString text );
-
-
+	bool useStunProxy;
+	QString stunProxyUri;
 };
 
 #endif // KPHONEVIEW_H_INCLUDED
