@@ -232,11 +232,9 @@ void KSipPreferences::slotApply( void )
 	switch( symMedia->id(symMedia->selected())) {
 	case symMediaYes:
 		settings.writeEntry("/kphone/Symmetric/Media", "Yes");
-		audio->setSymMediaMode(true);
 		break;
 	default:
 		settings.writeEntry("/kphone/Symmetric/Media", "No");
-		audio->setSymMediaMode(false);
 		break;
 	}
 }
