@@ -25,7 +25,6 @@ protected slots:
 private:
 	enum ExpProxy { DontUseExpProxy, UseExpProxy };
 	enum HideVia { NoHide, HideHop, HideRoute };
-	enum DefUserMode { DefMode, NoDefMode };
 	enum CallForward { FwActive, FwInactive };
 	enum Socket { UDP, TCP };
 	enum Stun { stunYes, stunNo };
@@ -46,7 +45,6 @@ private:
 	QMultiLineEdit *busymsg;
 	QButtonGroup *expbg;
 	QButtonGroup *hidebg;
-	QButtonGroup *usedef;
 	QButtonGroup *forbg;
 	QButtonGroup *stun;
 	QButtonGroup *symmetric;
