@@ -1,5 +1,7 @@
 
 #include <qapplication.h>
+#include <qtranslator.h>
+#include <qtextcodec.h>
 #include "kphone.h"
 
 int main( int argc, char **argv )
@@ -11,6 +13,12 @@ int main( int argc, char **argv )
 	bool strictRoute = false;
 
 	QApplication a( argc, argv );
+
+	// translation file for application strings
+	QTranslator myapp( 0 );
+	myapp.load( QString( "kphone_" ) + QTextCodec::locale(), PO_DIR );
+	a.installTranslator( &myapp );
+	
 	for ( int i = 0; i < a.argc(); i++ ) {
 		if( QString( a.argv()[i] ) == "-u" ) {
 			if( i+1 < a.argc() ) {
